[jbossws-commits] JBossWS SVN: r3822 - in trunk: build/ant-import and 14 other directories.

jbossws-commits at lists.jboss.org jbossws-commits at lists.jboss.org
Mon Jul 9 07:32:21 EDT 2007


Author: thomas.diesler at jboss.com
Date: 2007-07-09 07:32:21 -0400 (Mon, 09 Jul 2007)
New Revision: 3822

Added:
   trunk/jbossws-core/src/test/resources/jaxrpc/xop/xml-media-types.xsd
Modified:
   trunk/build/ant-import/build-release.xml
   trunk/build/build.xml
   trunk/build/dist/ReleaseNotes.txt
   trunk/build/version.properties
   trunk/integration/native/ant-import/build-bin-dist.xml
   trunk/integration/native/ant-import/build-release.xml
   trunk/integration/native/build.xml
   trunk/integration/native/src/main/etc/component-info40.xml
   trunk/integration/native/src/main/etc/component-info42.xml
   trunk/integration/native/src/main/etc/component-info50.xml
   trunk/integration/native/src/main/resources/jbossws-native42.sar/jbossws.beans/META-INF/jboss-beans.xml
   trunk/integration/native/version.properties
   trunk/integration/spi/src/main/etc/component-info.xml
   trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandler.java
   trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandlerFactory.java
   trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/WSContractConsumer.java
   trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/ant/WSConsumeTask.java
   trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/cmd/WSConsume.java
   trunk/jbossws-core/ant-import/build-release.xml
   trunk/jbossws-core/src/main/etc/component-info.xml
   trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/impl/SunRIConsumerImpl.java
   trunk/jbossws-core/src/test/resources/jaxrpc/xop/schema.xsd
Log:
Set the context class loader for handleRequest
Add revision switch to jaxws tools. Allows to specify the JAX-WS target specification (2.0|2.1)
Account for backward compatible bean name 'ServiceRefHandler'



Modified: trunk/build/ant-import/build-release.xml
===================================================================
--- trunk/build/ant-import/build-release.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/build/ant-import/build-release.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -24,7 +24,7 @@
     <echo message="*  - Update portal-content/counter.xml"/>
     <echo message="*  - Update news in portal-content/freezone/projectDescription.html"/>
     <echo message="*  - Verify release notes and install instructions"/>
-    <echo message="*  - Publish the interop endpoints (ant -f jboss-tests/build.xml publish-interop-endpoints)"/>
+    <echo message="*  - Publish the interop endpoints"/>
     <echo message="*  - Commit the portal-content"/>
     <echo message="*  - Commit the repository jars"/>
     <echo message="*  - Write a sticky post on the user forum"/>
@@ -47,12 +47,8 @@
   </target>
     
   <!-- Release to portal content -->
-  <target name="check-portal-content" depends="prepare" unless="jbossws.portal.content.available">
-    <echo message="*********************************************"/>
-    <echo message="* Not available: ${jbossws.portal.content}"/>
-    <echo message="*********************************************"/>
-  </target>
-  <target name="release-to-portal" depends="check-portal-content" description="Release to portal-content" if="jbossws.portal.content.available">
+  <target name="release-to-portal" depends="check-portal-content, build-src-dist" 
+    description="Release to portal-content" if="jbossws.portal.content.available">
     
     <property name="portal.freezone" value="${jbossws.portal.content}/freezone"/>
     <property name="portal.userguide" value="${portal.freezone}/user-guide"/>
@@ -60,20 +56,36 @@
     
     <!-- Copy downloads -->
     <copy todir="${portal.downloads}" overwrite="true">
-      <fileset dir="${build.output.dir}">
-        <include name="jbossws-${version.id}.zip"/>
+      <fileset dir="${build.dir}/output">
         <include name="jbossws-src-${version.id}.zip"/>
-        <include name="jbossws-samples-${version.id}.zip"/>
       </fileset>
+      <fileset dir="${int.native.dir}/output">
+        <include name="jbossws-native-${version.id}.zip"/>
+      </fileset>
     </copy>
     
     <!-- Copy Release Notes -->
-    <copy tofile="${portal.downloads}/ReleaseNotes-${version.id}.txt" file="${build.bin.dist}/ReleaseNotes.txt" overwrite="true"/>
-    <copy tofile="${portal.downloads}/Install-${version.id}.txt" file="${build.bin.dist}/Install.txt" overwrite="true"/>
+		<copy todir="${build.dir}/output" filtering="yes">
+			<fileset dir="${build.dir}/dist">
+        <include name="Install.txt"/>
+        <include name="ReleaseNotes.txt"/>
+      </fileset>
+      <filterset>
+        <filtersfile file="${build.dir}/version.properties"/>
+      </filterset>
+		</copy>
+    <copy tofile="${portal.downloads}/ReleaseNotes-${version.id}.txt" file="${build.dir}/output/ReleaseNotes.txt" overwrite="true"/>
+    <copy tofile="${portal.downloads}/Install-${version.id}.txt" file="${build.dir}/output/Install.txt" overwrite="true"/>
   </target>
-
+  
+  <target name="check-portal-content" depends="prepare" unless="jbossws.portal.content.available">
+    <echo message="*********************************************"/>
+    <echo message="* Not available: ${jbossws.portal.content}"/>
+    <echo message="*********************************************"/>
+  </target>
+  
   <!-- ================================================================== -->
-  <!-- Build distributions                                                -->
+  <!-- Build source distributions                                                -->
   <!-- ================================================================== -->
 
   <!-- Build the src dist -->
@@ -83,31 +95,14 @@
     <mkdir dir="${build.src.dist}/jbossws-src-${version.id}"/>
     <copy todir="${build.src.dist}/jbossws-src-${version.id}">
       <fileset dir="${basedir}">
-        <exclude name="*.md5"/>
+        <exclude name="**/*.md5"/>
         <exclude name="**/output*/**"/>
         <exclude name="**/thirdparty/**"/>
+        <exclude name="mergeinfo.txt"/>
       </fileset>
     </copy>
     <zip destfile="${build.dir}/output/jbossws-src-${version.id}.zip" basedir="${build.src.dist}"
       includes="jbossws-src-${version.id}/**"/>
   </target>
-  
-  <!-- ================================================================== -->
-  <!-- Documentation                                                      -->
-  <!-- ================================================================== -->
 
-  <!-- Generate the JavaDoc -->
-  <target name="build-javadoc" depends="prepare" description="Generate the Javadoc">
-    <mkdir dir="${build.output.dir}/docs/api"/>
-    <javadoc destdir="${build.output.dir}/docs/api" author="true" version="true" use="true" windowtitle="JBossWS API">
-      <packageset dir="${core.java.dir}" defaultexcludes="yes"/>
-      <packageset dir="${jboss42.java.dir}" defaultexcludes="yes"/>
-      <packageset dir="${jboss50.java.dir}" defaultexcludes="yes"/>
-      <packageset dir="${tomcat.java.dir}" defaultexcludes="yes"/>
-      <classpath refid="core.classpath"/>
-    </javadoc>
-    <zip destfile="${build.output.dir}/jbossws-${version.id}-api.zip" basedir="${build.output.dir}/docs"
-      includes="api/**"/>
-  </target>
-
 </project>

Modified: trunk/build/build.xml
===================================================================
--- trunk/build/build.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/build/build.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -122,6 +122,7 @@
   <!-- ================================================================== -->
   
   <target name="clean" depends="prepare" description="Cleans up most generated files.">
+    <delete dir="${build.dir}/output"/>
     <ant antfile="${spi.dir}/build.xml" target="clean" inheritall="false"/>
     <ant antfile="${core.dir}/build.xml" target="clean" inheritall="false"/>
     <ant antfile="${int.jboss50.dir}/build.xml" target="clean" inheritall="false"/>
@@ -134,6 +135,7 @@
   </target>
   
   <target name="clobber" depends="prepare" description="Cleans up all generated files.">
+    <delete dir="${build.dir}/output"/>
     <ant antfile="${spi.dir}/build.xml" target="clobber" inheritall="false"/>
     <ant antfile="${core.dir}/build.xml" target="clobber" inheritall="false"/>
     <ant antfile="${testsuite.dir}/build.xml" target="clobber" inheritall="false"/>

Modified: trunk/build/dist/ReleaseNotes.txt
===================================================================
--- trunk/build/dist/ReleaseNotes.txt	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/build/dist/ReleaseNotes.txt	2007-07-09 11:32:21 UTC (rev 3822)
@@ -7,9 +7,12 @@
 Release Notes
 =============
 
-The UserGuide accessible from http://labs.jboss.com/portal/jbossws is usally a good starting point
-A list of examples that accompany the UserGuide can be found in the samples
+The wiki (http://labs.jboss.com/portal/jbossws/) is usally a good starting point.
+It contains the User Guide and Quick Start instructions.
 
+A list of examples that accompany the UserGuide can be found in the tests directory
+that ship with the distribution.
+
 If you have any questions, please post to the JBossWS User Forum
 http://www.jboss.org/index.html?module=bb&op=viewforum&f=200
 
@@ -24,6 +27,98 @@
 
 Feature Request
 
+    * [JBWS-434] - Support sequences of anys in JAXRPC
+    * [JBWS-1460] - @XmlMimeType and @XmlAttachmentRef on SEI parameter declarations
+    * [JBWS-1518] - Add support for jdk-1.6
+    * [JBWS-1597] - WSDL To Java - Add support for bound headers.
+    * [JBWS-1666] - Simplify jbosws jar dependencies
+    * [JBWS-1564] - Support swaRef with JAX-WS
+    * [JBWS-1618] - Make default context root for jaxws ejb endpoint configurable
+    * [JBWS-429] - WSDL To Java - Create Custom Holders for Custom types that define INOUT parameters and OUT parameters
+    * [JBWS-771] - Use part names that are friendly to .NET
+
+Bug
+
+    * [JBWS-801] - Chunked transfer of large attachments
+    * [JBWS-805] - Fault code is always 'Client'
+    * [JBWS-859] - SOAPMessageUnMarshaller doesn't support HTTP server response [204] - No Content
+    * [JBWS-862] - Return SOAP Fault for invalid soap messages
+    * [JBWS-1093] - Deploying a war that also contains normal servlets the web.xml is modified as if they are all endpoints
+    * [JBWS-1263] - Addressing does not disable the mustUnderstand attribute, which causes HandlerchainBaseImple.checkMustUnderstand to fail
+    * [JBWS-1283] - Soap attachments were dropped on server responses. Attachment is added on a handler's handleResponse method; however it mysteriously disappeared on the outgoing soap message.
+    * [JBWS-1339] - @Security domain vs. <security-domain>
+    * [JBWS-1346] - wsa:ReplyTo alwayt null
+    * [JBWS-1403] - NumberFormatException When Using StubExt.PROPERTY_CLIENT_TIMEOUT
+    * [JBWS-1422] - NPE if @WebParam.name like "mX.."
+    * [JBWS-1439] - Jdk 1.6.0 Requests get the error "setProperty must be overridden by all subclasses of SOAPMessage"
+    * [JBWS-1446] - Invalid WSDL when a parameter of type Object is part of a webmethod
+    * [JBWS-1468] - @Resource WebServiceContext for jbossas-4.x
+    * [JBWS-1472] - Address in WSDL is now always replaced regardless of 'alwaysModifySOAPAddress' value.
+    * [JBWS-1511] - MessageFactory does not preserve comments
+    * [JBWS-1520] - No server response on invalid soap request
+    * [JBWS-1553] - fails to read operations for portType from different namespace
+    * [JBWS-1556] - @WebWservice does not work with class isolation
+    * [JBWS-1563] - WSDLDefinitionsFactory doesn't resolve schema references locally
+    * [JBWS-1566] - JBossWS-1.2.0.GA invalid wsdl generated when using @XmlSchema annotations on Types inheriting from >1 java package
+    * [JBWS-1579] - @EndpointConfig ignored on SEI
+    * [JBWS-1588] - Review jar in classpath for wsrunclient.sh
+    * [JBWS-1594] - Support certificate password different from keystore
+    * [JBWS-1595] - No typemapping for xsd:anyType with soap encoding
+    * [JBWS-1607] - WSDL To Java - document/literal, IN OUT parameter incorectly used as return type.
+    * [JBWS-1609] - Address in WSDL - Port value is -1 when server is requested with default port 80
+    * [JBWS-1611] - SOAPAction is not sent in dispath requests
+    * [JBWS-1616] - Verify correct bahaviour of @WebService.wsdlLocation
+    * [JBWS-1619] - ServletEndpointContext.getHttpSession always creates HTTPSession
+    * [JBWS-1620] - Incorrect handling of MIME boundaries in MultipartRelatedDecoder
+    * [JBWS-1621] - wstools.sh contain the wrong client libs and will fail
+    * [JBWS-1622] - Multiple context root not supported
+    * [JBWS-1624] - JBossWS samples don't work with JMX authentication
+    * [JBWS-1625] - Calling SOAPPart.setContent() with a DOMSource containing an Element which is a SOAPElement the contents of the body are added twice.
+    * [JBWS-1627] - WSDL To Java - Array Unwrapping uses incorect case to reference array type.
+    * [JBWS-1647] - Text Node Preservation For Messages Sent Across The Wire
+    * [JBWS-1653] - Post-handler-chain not invoked for "Standard Client" configuration
+    * [JBWS-1657] - Error resolving swaref schema
+    * [JBWS-1658] - SwaRef fails with doclit/wrapped endpoints
+    * [JBWS-1659] - @XmlAttachmentRef ignored on method level
+    * [JBWS-1660] - Resolve swaref schema through entity resolver
+    * [JBWS-1680] - Dispatch.invoke does not throw a ProtocolException on Fault
+    * [JBWS-1690] - Review wstools scripts and jars copied to client.
+    * [JBWS-1691] - WSDL To Java - Initial Character of Service and SEI names should be upper case.
+    * [JBWS-1692] - SOAPElement.importNode() not supported
+    * [JBWS-1696] - MIssing wsdl4j.jar in scripts
+    * [JBWS-1697] - WSDL To Java - Incorrect handling of Simple types derived by restriction for holders.
+    * [JBWS-1698] - WSDL To Java - If fault name contains 'Fault' the generated Exception does not match the throws clause on the SEI
+    * [JBWS-1706] - SOAPConnection.get fails with ProtocolException
+    * [JBWS-1710] - StackOverflowError when calling SOAPDocument.createCDATASection
+    * [JBWS-1711] - NoClassDefFoundError: com/sun/xml/stream/buffer/XMLStreamBuffer
+
+Task
+
+    * [JBWS-1661] - Update to jaxb-ri-2.1
+
+Errata
+------
+    FIXME: [JBAS-3595] - Tomcat allows http access with transport guarantie CONFIDENTIAL
+    FIXME: [JBWEB-68] Servlet.init(ServletConfig) not called
+    FIXME: [JBCTS-540] EJB3 proxy does not implement the Home interface
+    FIXME: [JBWS-1312] Fix JMS transport in trunk
+    FIXME: [JBWS-1330] Fix jaxrpc wsse tests for jbossws-5.0
+    FIXME: [JBWS-1397] Fix <wsdl-publish-location> for jboss-5.0.x
+    FIXME: [JBWS-1460] @XmlMimeType on SEI parameter declarations
+    FIXME: [JBWS-1617] JAXRPC doc/literal trims empty string
+    FIXME: [JBWS-751] Multiple schema imports with the same namespace
+    FIXME: [JBWS-798] Complete EventingTestCase
+    FIXME: [JBWS-981] Virtual host configuration for EJB endpoints
+    
+Enjoy,
+The JBossWS Team
+
+Previous Releases ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+What's new in JBossWS-1.2.1
+---------------------------
+Feature Request
+
     * [JBWS-1156] - Implement injection of WebServiceRef
     * [JBWS-1021] - Implement javax.xml.ws.Endpoint
     * [JBWS-1022] - Implement javax.xml.ws.WebServiceContext
@@ -111,11 +206,6 @@
     FIXME: [JBWS-434] Support sequences of anys in JAXRPC
     FIXME: [JBWS-751] Multiple schema imports with the same namespace
 
-Enjoy,
-The JBossWS Team
-
-Previous Releases ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
 What's new in jbossws-1.0.4
 ---------------------------
 

Modified: trunk/build/version.properties
===================================================================
--- trunk/build/version.properties	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/build/version.properties	2007-07-09 11:32:21 UTC (rev 3822)
@@ -6,7 +6,7 @@
 specification.version=jbossws-2.1
 
 version.id=2.1.0.DEV
-repository.id=snapshot
+repository.id=2.0.0.GA
 
 implementation.title=JBoss Web Services - JBossWS
 implementation.url=http://www.jboss.org/products/jbossws

Modified: trunk/integration/native/ant-import/build-bin-dist.xml
===================================================================
--- trunk/integration/native/ant-import/build-bin-dist.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/ant-import/build-bin-dist.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -42,7 +42,6 @@
     </copy>
 		<copy tofile="${bindist.dir}/build.xml" file="${native.etc.dir}/bin-dist-build.xml"/>
 		<copy tofile="${bindist.build.dir}/build-deploy.xml" file="${native.etc.dir}/bin-dist-deploy.xml"/>
-		<copy todir="${bindist.dir}" file="${native.dir}/version.properties"/>
 
 		<!-- build -->
 		<copy todir="${bindist.build.dir}">
@@ -87,9 +86,20 @@
 
 
 		<!-- docs -->
-		<zip destfile="${bindist.docs.dir}/apidocs-${version.id}.zip">
-			<fileset dir="${native.output.dir}/apidocs"/>
-		</zip>
+		<copy todir="${bindist.docs.dir}" >
+			<fileset dir="${native.output.dir}">
+        <include name="apidocs/**"/>
+      </fileset>
+		</copy>
+		<copy todir="${bindist.docs.dir}" filtering="yes">
+			<fileset dir="${build.dir}/dist">
+        <include name="Install.txt"/>
+        <include name="ReleaseNotes.txt"/>
+      </fileset>
+      <filterset>
+        <filtersfile file="${build.dir}/version.properties"/>
+      </filterset>
+		</copy>
 
 		<copy todir="${bindist.docs.dir}">
 			<fileset dir="${build.dir}/etc">

Modified: trunk/integration/native/ant-import/build-release.xml
===================================================================
--- trunk/integration/native/ant-import/build-release.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/ant-import/build-release.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -26,11 +26,7 @@
         <include name="jbossws-native50-deployer.zip"/>
       </fileset>
     </copy>
-    <copy tofile="${jboss.repository.dir}/jbossws-native50/${repository.id}/component-info.xml" file="${native.etc.dir}/component-info50.xml" filtering="true" overwrite="true">
-      <filterset>
-        <filtersfile file="${build.dir}/version.properties"/>
-      </filterset>
-    </copy>
+    <copy tofile="${jboss.repository.dir}/jbossws-native50/${repository.id}/component-info.xml" file="${native.output.etc.dir}/component-info50.xml" overwrite="true"/>
     
     <!-- jboss/jbossws-native42 -->
     <property name="jboss.repository.dir" value="${jboss.local.repository}/jboss"/>
@@ -40,11 +36,7 @@
         <include name="jbossws-native42.sar"/>
       </fileset>
     </copy>
-    <copy tofile="${jboss.repository.dir}/jbossws-native42/${repository.id}/component-info.xml" file="${native.etc.dir}/component-info42.xml" filtering="true" overwrite="true">
-      <filterset>
-        <filtersfile file="${build.dir}/version.properties"/>
-      </filterset>
-    </copy>
+    <copy tofile="${jboss.repository.dir}/jbossws-native42/${repository.id}/component-info.xml" file="${native.output.etc.dir}/component-info42.xml" overwrite="true"/>
     
     <!-- jboss/jbossws-native40 -->
     <property name="jboss.repository.dir" value="${jboss.local.repository}/jboss"/>
@@ -54,11 +46,7 @@
         <include name="jbossws-native40.sar"/>
       </fileset>
     </copy>
-    <copy tofile="${jboss.repository.dir}/jbossws-native40/${repository.id}/component-info.xml" file="${native.etc.dir}/component-info40.xml" filtering="true" overwrite="true">
-      <filterset>
-        <filtersfile file="${build.dir}/version.properties"/>
-      </filterset>
-    </copy>
+    <copy tofile="${jboss.repository.dir}/jbossws-native40/${repository.id}/component-info.xml" file="${native.output.etc.dir}/component-info40.xml" overwrite="true"/>
     
   </target>
 

Modified: trunk/integration/native/build.xml
===================================================================
--- trunk/integration/native/build.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/build.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -71,9 +71,9 @@
   <!-- Compile etc files (manifests and such) -->
   <target name="compile-etc" depends="init">
     <mkdir dir="${native.output.etc.dir}"/>
-    <copy todir="${native.output.etc.dir}" filtering="yes">
+    <copy todir="${native.output.etc.dir}" filtering="yes" overwrite="true">
       <fileset dir="${native.etc.dir}">
-        <include name="component-info-*.xml"/>
+        <include name="component-info*.xml"/>
   	  </fileset>
       <fileset dir="${build.dir}/etc">
         <include name="default.mf"/>
@@ -84,6 +84,7 @@
         <filter token="build.id" value="${build.id}"/>
         <filter token="implementation.version" value="jbossws-native-${version.id}"/>
         <filtersfile file="${build.dir}/version.properties"/>
+        <filtersfile file="${native.dir}/version.properties"/>
       </filterset>
     </copy>
   </target>

Modified: trunk/integration/native/src/main/etc/component-info40.xml
===================================================================
--- trunk/integration/native/src/main/etc/component-info40.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/src/main/etc/component-info40.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -10,15 +10,12 @@
     <import componentref="jboss/jbossxb">
       <compatible version="@jboss-jbossxb@"/>
     </import>
-    <import componentref="jboss/microcontainer">
-      <compatible version="@jboss-microcontainer@"/>
+    <import componentref="jboss/remoting">
+      <compatible version="@jboss-remoting-jboss40@"/>
     </import>
     <import componentref="jboss/jbossws">
       <compatible version="@repository.id@"/>
     </import>
-    <import componentref="jboss/jbossws-jboss50">
-      <compatible version="@repository.id@"/>
-    </import>
     <import componentref="jboss/jbossws-spi">
       <compatible version="@repository.id@"/>
     </import>

Modified: trunk/integration/native/src/main/etc/component-info42.xml
===================================================================
--- trunk/integration/native/src/main/etc/component-info42.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/src/main/etc/component-info42.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -7,18 +7,21 @@
     
     <artifact id="jbossws-native42.sar"/>
     
+    <import componentref="javassist">
+      <compatible version="@javassist-jboss42@"/>
+      <compatible version="@javassist-jboss42 at -brew"/>
+    </import>
     <import componentref="jboss/jbossxb">
-      <compatible version="@jboss-jbossxb@"/>
+      <compatible version="@jboss-jbossxb-jboss42@"/>
+      <compatible version="@jboss-jbossxb-jboss42 at -brew"/>
     </import>
-    <import componentref="jboss/microcontainer">
-      <compatible version="@jboss-microcontainer@"/>
+    <import componentref="jboss/remoting">
+      <compatible version="@jboss-remoting-jboss42@"/>
+      <compatible version="@jboss-remoting-jboss42 at -brew"/>
     </import>
     <import componentref="jboss/jbossws">
       <compatible version="@repository.id@"/>
     </import>
-    <import componentref="jboss/jbossws-jboss50">
-      <compatible version="@repository.id@"/>
-    </import>
     <import componentref="jboss/jbossws-spi">
       <compatible version="@repository.id@"/>
     </import>

Modified: trunk/integration/native/src/main/etc/component-info50.xml
===================================================================
--- trunk/integration/native/src/main/etc/component-info50.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/src/main/etc/component-info50.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -8,18 +8,18 @@
     <artifact id="jbossws-native50.sar"/>
     <artifact id="jbossws-native50-deployer.zip"/>
     
+    <import componentref="javassist">
+      <compatible version="@javassist-jboss50@"/>
+    </import>
     <import componentref="jboss/jbossxb">
-      <compatible version="@jboss-jbossxb@"/>
+      <compatible version="@jboss-jbossxb-jboss50@"/>
     </import>
-    <import componentref="jboss/microcontainer">
-      <compatible version="@jboss-microcontainer@"/>
+    <import componentref="jboss/remoting">
+      <compatible version="@jboss-remoting-jboss50@"/>
     </import>
     <import componentref="jboss/jbossws">
       <compatible version="@repository.id@"/>
     </import>
-    <import componentref="jboss/jbossws-jboss50">
-      <compatible version="@repository.id@"/>
-    </import>
     <import componentref="jboss/jbossws-spi">
       <compatible version="@repository.id@"/>
     </import>

Modified: trunk/integration/native/src/main/resources/jbossws-native42.sar/jbossws.beans/META-INF/jboss-beans.xml
===================================================================
--- trunk/integration/native/src/main/resources/jbossws-native42.sar/jbossws.beans/META-INF/jboss-beans.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/src/main/resources/jbossws-native42.sar/jbossws.beans/META-INF/jboss-beans.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -34,7 +34,9 @@
   </bean>
   
   <!-- Bind Service objects in client environment context  -->
-  <!-- The bean name is compiled into the server. Changeit with the next release. -->
+  <bean name="WSServiceRefHandler" class="org.jboss.ws.core.client.ServiceRefHandlerImpl"/>
+  
+  <!-- Note, JBoss_4_2_0_GA uses this hardcoded bean name -->
   <bean name="ServiceRefHandler" class="org.jboss.ws.core.client.ServiceRefHandlerImpl"/>
   
   <!-- Locate the single instance of the kernel -->  

Modified: trunk/integration/native/version.properties
===================================================================
--- trunk/integration/native/version.properties	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/native/version.properties	2007-07-09 11:32:21 UTC (rev 3822)
@@ -3,3 +3,16 @@
 
 native.implementation.title=JBoss Web Services - JBossWS/Native
 
+# JBossAS-5.0
+javassist-jboss50=3.5.0.CR1
+jboss-jbossxb-jboss50=2.0.0.CR2
+jboss-remoting-jboss50=2.2.0.GA
+
+# JBossAS-4.2
+javassist-jboss42=3.5.0.GA
+jboss-jbossxb-jboss42=1.0.0.GA
+jboss-remoting-jboss42=2.2.1.GA
+
+# JBossAS-4.0
+jboss-jbossxb-jboss40=1.0.0.GA
+jboss-remoting-jboss40=1.4.3.GA

Modified: trunk/integration/spi/src/main/etc/component-info.xml
===================================================================
--- trunk/integration/spi/src/main/etc/component-info.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/spi/src/main/etc/component-info.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -1,31 +1,29 @@
 <project name="jboss/jbossws-spi">
+	<artifact id="jbossws-spi-src.zip"/>
+	<artifact id="jbossws-spi-scripts.zip"/>
+	
+  <component id="jboss/jbossws-spi" description="JBossWS SPI" version="@repository.id@" licenseType="lgpl">
+    
+    <artifact id="jbossws-spi.jar"/>
     <artifact id="jbossws-spi-scripts.zip"/>
-
-	<component id="jboss/jbossws-spi"
-				  description="JBossWS SPI"
-				  version="@repository.id@"
-				  licenseType="lgpl">
-
-		<artifact id="jbossws-spi.jar"/>
-		<artifact id="jbossws-spi-scripts.zip"/>
-
-		<import componentref="sun-jaxb">
-			<compatible version="@sun-jaxb@"/>
-		</import>
-
-		<import componentref="sun-jaxws">
-			<compatible version="@sun-jaxws@"/>
-		</import>
-
-		<import componentref="woodstox">
-			<compatible version="@woodstox@"/>
-		</import>
-		
-		<export>
-			<include input="jbossws-spi.jar"/>
-			<include input="jbossws-spi-scripts.zip"/>
-		</export>
-
-	</component>
-
+    
+    <import componentref="sun-jaxb">
+      <compatible version="@sun-jaxb@"/>
+    </import>
+    
+    <import componentref="sun-jaxws">
+      <compatible version="@sun-jaxws@"/>
+    </import>
+    
+    <import componentref="woodstox">
+      <compatible version="@woodstox@"/>
+    </import>
+    
+    <export>
+      <include input="jbossws-spi.jar"/>
+      <include input="jbossws-spi-scripts.zip"/>
+    </export>
+    
+  </component>
+	
 </project>

Modified: trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandler.java
===================================================================
--- trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandler.java	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandler.java	2007-07-09 11:32:21 UTC (rev 3822)
@@ -37,6 +37,8 @@
  */
 public interface ServiceRefHandler
 {
+   final String BEAN_NAME = "WSServiceRefHandler";
+   
    ServiceRefMetaData newServiceRefMetaData();
 
    Object newChild(ServiceRefElement ref, UnmarshallingContext navigator, String namespaceURI, String localName, Attributes attrs);

Modified: trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandlerFactory.java
===================================================================
--- trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandlerFactory.java	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/spi/src/main/java/org/jboss/ws/integration/ServiceRefHandlerFactory.java	2007-07-09 11:32:21 UTC (rev 3822)
@@ -54,7 +54,7 @@
    {
       Kernel kernel = KernelLocator.getKernel();
       KernelRegistry registry = kernel.getRegistry();
-      KernelRegistryEntry entry = registry.getEntry("WSServiceRefHandler");
+      KernelRegistryEntry entry = registry.getEntry(ServiceRefHandler.BEAN_NAME);
       ServiceRefHandler handler = (ServiceRefHandler)entry.getTarget();
 
       // Try legancy JBossAS-4.2 name

Modified: trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/WSContractConsumer.java
===================================================================
--- trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/WSContractConsumer.java	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/WSContractConsumer.java	2007-07-09 11:32:21 UTC (rev 3822)
@@ -48,7 +48,7 @@
     * Obtain a new instance of a WSContractProvider. This will use the current
     * thread's context class loader to locate the WSContractProviderFactory
     * implementation.
-    * 
+    *
     * @return a new WSContractProvider
     */
    public static WSContractConsumer newInstance()
@@ -59,7 +59,7 @@
    /**
     * Obtain a new instance of a WSContractConsumer. The specified ClassLoader will be used to
     * locate the WebServiceImporterProvide implementation
-    * 
+    *
     * @param loader the ClassLoader to use
     * @return a new WSContractConsumer
     */
@@ -80,37 +80,37 @@
 
    /**
     * Specifies the JAX-WS and JAXB binding files to use on import operations.
-    * 
+    *
     * @param bindingFiles list of JAX-WS or JAXB binding files
     */
    public abstract void setBindingFiles(List<File> bindingFiles);
 
    /**
     * Sets the OASIS XML Catalog file to use for entity resolution.
-    * 
+    *
     * @param catalog the OASIS XML Catalog file
     */
    public abstract void setCatalog(File catalog);
 
    /**
     * Sets the main output directory. If the directory does not exist, it will be created.
-    * 
+    *
     * @param directory the root directory for generated files
     */
    public abstract void setOutputDirectory(File directory);
 
    /**
     * Sets the source directory. This directory will contain any generated Java source.
-    * If the directory does not exist, it will be created. If not specified, 
+    * If the directory does not exist, it will be created. If not specified,
     * the output directory will be used instead.
-    * 
+    *
     * @param directory the root directory for generated source code
     */
    public abstract void setSourceDirectory(File directory);
 
    /**
     * Enables/Disables Java source generation.
-    * 
+    *
     * @param generateSource whether or not to generate Java source.
     */
    public abstract void setGenerateSource(boolean generateSource);
@@ -118,14 +118,14 @@
    /**
     * Sets the target package for generated source. If not specified the default
     * is based off of the XML namespace.
-    * 
+    *
     * @param targetPackage the target package for generated source
     */
    public abstract void setTargetPackage(String targetPackage);
 
    /**
     * Sets the @@WebService.wsdlLocation and @@WebServiceClient.wsdlLocation attributes to a custom value.
-    * 
+    *
     * @param wsdlLocation the custom WSDL location to use in generated source
     */
    public abstract void setWsdlLocation(String wsdlLocation);
@@ -133,25 +133,31 @@
    /**
     * Sets the PrintStream to use for status feedback. The simplest example
     * would be to use System.out.
-    * 
+    *
     * @param messageStream  the stream to use for status messages:
     */
    public abstract void setMessageStream(PrintStream messageStream);
 
    /**
     * Sets the additional classpath to use if/when invoking the Java compiler.
-    * Typically an implementation will use the system <code>java.class.path</code> 
+    * Typically an implementation will use the system <code>java.class.path</code>
     * property. So for most normal applications this method is not needed. However,
     * if this API is being used from an isolated classloader, then it needs to
-    * be called in order to reference all jars that are required by the 
+    * be called in order to reference all jars that are required by the
     * implementation.
-    * 
-    * @param classPath a list of strings where each entry references a 
+    *
+    * @param classPath a list of strings where each entry references a
     *                  single jar or directory
     */
    public abstract void setAdditionalCompilerClassPath(List<String> classPath);
 
    /**
+    * Set the target JAX-WS specification target. Defaults to <code>2.0</code>
+    * @param target  the JAX-WS specification version. Allowed values are 2.0, 2.1
+    */
+   public abstract void setTarget(String target);
+
+   /**
     * Generate the required artifacts using the specified WSDL URL. This method
     * may be called more than once, although this is probably not desireable
     * 

Modified: trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/ant/WSConsumeTask.java
===================================================================
--- trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/ant/WSConsumeTask.java	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/ant/WSConsumeTask.java	2007-07-09 11:32:21 UTC (rev 3822)
@@ -1,27 +1,37 @@
 /*
-* JBoss, Home of Professional Open Source
-* Copyright 2005, JBoss Inc., and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
 package org.jboss.wsf.spi.tools.ant;
 
-import org.apache.tools.ant.*;
+import java.io.File;
+import java.io.PrintStream;
+import java.net.MalformedURLException;
+import java.util.ArrayList;
+import java.util.List;
+
+import org.apache.tools.ant.AntClassLoader;
+import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.DirectoryScanner;
+import org.apache.tools.ant.Project;
+import org.apache.tools.ant.Task;
 import org.apache.tools.ant.taskdefs.ExecuteJava;
 import org.apache.tools.ant.taskdefs.LogOutputStream;
 import org.apache.tools.ant.types.Commandline;
@@ -30,15 +40,9 @@
 import org.apache.tools.ant.types.Path;
 import org.jboss.wsf.spi.tools.WSContractConsumer;
 
-import java.io.File;
-import java.io.PrintStream;
-import java.net.MalformedURLException;
-import java.util.ArrayList;
-import java.util.List;
-
 /**
  * Ant task which consumes a Web Service contract.
- * 
+ *
  * <table border="1">
  *   <tr align="left" BGCOLOR="#CCCCFF" CLASS="TableHeadingColor"><th>Attribute</th><th>Description</th><th>Default</th></tr>
  *   <tr><td>fork</td><td>Whether or not to run the generation task in a separate VM.</td><td>true</td></tr>
@@ -49,13 +53,14 @@
  *   <tr><td>wsdlLocation</td><td>Value to use for @@WebService.wsdlLocation</td><td>generated</td></tr>
  *   <tr><td>destdir</td><td>The output directory for generated artifacts.</td><td>"output"</td></tr>
  *   <tr><td>sourcedestdir</td><td>The output directory for Java source.</td><td>value of destdir</td></tr>
+ *   <tr><td>target</td><td>The JAX-WS specification target</td><td>2.0 | 2.1</td></tr>
  *   <tr><td>verbose</td><td>Enables more informational output about cmd progress.</td><td>false</td><tr>
  *   <tr><td>wsdl*</td><td>The WSDL file or URL</td><td>n/a</td><tr>
  * </table>
  * <b>* = required.</b>
- * 
+ *
  * <p>Example:
- * 
+ *
  * <pre>
  * &lt;WSConsumeTask
  *   fork=&quot;true&quot;
@@ -63,36 +68,37 @@
  *   destdir=&quot;output&quot;
  *   sourcedestdir=&quot;gen-src&quot;
  *   keep=&quot;true&quot;
- *   wsdllocation=&quot;handEdited.wsdl&quot; 
+ *   wsdllocation=&quot;handEdited.wsdl&quot;
  *   wsdl=&quot;foo.wsdl&quot;&gt;
  *   &lt;binding dir=&quot;binding-files&quot; includes=&quot;*.xml&quot; excludes=&quot;bad.xml&quot;/&gt;
  * &lt;/wsimport&gt;
  * </pre>
- * 
+ *
  * @author <a href="mailto:jason.greene at jboss.com">Jason T. Greene</a>
  * @version $Revision$
  */
 public class WSConsumeTask extends Task
 {
    private CommandlineJava command = new CommandlineJava();
-   private String wsdl = null;
-   private File destdir = null;
-   private File sourcedestdir = null;
+   private String wsdl;
+   private File destdir;
+   private File sourcedestdir;
    private List<File> bindingFiles = new ArrayList<File>();
-   private File catalog = null;
-   private String wsdlLocation = null;
-   private String targetPackage = null;
-   private boolean keep = false;
-   private boolean verbose = false;
-   private boolean fork = false;
-   private boolean debug = false;
-   
+   private File catalog;
+   private String wsdlLocation;
+   private String targetPackage;
+   private boolean keep;
+   private boolean verbose;
+   private boolean fork;
+   private boolean debug;
+   private String target;
+
    // Not actually used right now
    public void setDebug(boolean debug)
    {
       this.debug = debug;
    }
-   
+
    public Commandline.Argument createJvmarg()
    {
       return command.createVmArgument();
@@ -128,6 +134,11 @@
       this.sourcedestdir = sourcedestdir;
    }
 
+   public void setTarget(String target)
+   {
+      this.target = target;
+   }
+
    public void setPackage(String targetPackage)
    {
       this.targetPackage = targetPackage;
@@ -147,7 +158,7 @@
    {
       this.wsdlLocation = wsdlLocation;
    }
-   
+
    public void addConfiguredBinding(FileSet fs)
    {
       DirectoryScanner ds = fs.getDirectoryScanner(getProject());
@@ -179,17 +190,19 @@
             importer.setCatalog(catalog);
          if (bindingFiles != null && bindingFiles.size() > 0)
             importer.setBindingFiles(bindingFiles);
-         
+         if (target != null)
+            importer.setTarget(target);
+
          log("Consuming wsdl: " + wsdl, Project.MSG_INFO);
-         
+
          if (verbose)
          {
             importer.setMessageStream(new PrintStream(new LogOutputStream(this, Project.MSG_INFO)));
          }
-         
+
          try
          {
-            importer.setAdditionalCompilerClassPath(getTaskClassPathStrings());            
+            importer.setAdditionalCompilerClassPath(getTaskClassPathStrings());
             importer.consume(wsdl);
          }
          catch (MalformedURLException e)
@@ -207,13 +220,12 @@
    {
       if (wsdl == null)
          throw new BuildException("The wsdl attribute must be specified!", getLocation());
-      
+
       if (fork)
          executeForked();
-      else
-         executeNonForked();
+      else executeNonForked();
    }
-   
+
    private Path getTaskClassPath()
    {
       // Why is everything in the Ant API a big hack???
@@ -222,10 +234,10 @@
       {
          return new Path(getProject(), ((AntClassLoader)cl).getClasspath());
       }
-      
+
       return new Path(getProject());
    }
-   
+
    private List<String> getTaskClassPathStrings()
    {
       // Why is everything in the Ant API a big hack???
@@ -236,66 +248,72 @@
          for (String string : ((AntClassLoader)cl).getClasspath().split(File.pathSeparator))
             strings.add(string);
       }
-      
+
       return strings;
    }
 
    private void executeForked() throws BuildException
    {
       command.setClassname(org.jboss.wsf.spi.tools.cmd.WSConsume.class.getName());
-      
+
       Path path = command.createClasspath(getProject());
       path.append(getTaskClassPath());
-     
+
       if (keep)
          command.createArgument().setValue("-k");
-     
+
       for (File file : bindingFiles)
       {
          command.createArgument().setValue("-b");
          command.createArgument().setFile(file);
       }
-      
+
       if (catalog != null)
       {
          command.createArgument().setValue("-c");
          command.createArgument().setFile(catalog);
       }
-      
+
       if (targetPackage != null)
       {
          command.createArgument().setValue("-p");
          command.createArgument().setValue(targetPackage);
       }
-      
+
       if (wsdlLocation != null)
       {
          command.createArgument().setValue("-w");
          command.createArgument().setValue(wsdlLocation);
       }
-         
+
       if (destdir != null)
       {
          command.createArgument().setValue("-o");
          command.createArgument().setFile(destdir);
       }
-      
+
       if (sourcedestdir != null)
       {
          command.createArgument().setValue("-s");
          command.createArgument().setFile(sourcedestdir);
       }
-      
-      if (!verbose)
-         command.createArgument().setValue("-q");
-      
-      // Always dump traces
-      command.createArgument().setValue("-t");
+
+      if (target != null)
+      {
+         command.createArgument().setValue("-t");
+         command.createArgument().setValue(target);
+      }
+
+      if (verbose)
+         command.createArgument().setValue("-v");
+
       command.createArgument().setValue(wsdl);
+
+      log("Consuming wsdl: " + wsdl, Project.MSG_INFO);
       
       if (verbose)
          log("Command invoked: " + command.getJavaCommand().toString());
-      
+
       ExecuteJava execute = new ExecuteJava();
       execute.setClasspath(path);
       execute.setJavaCommand(command.getJavaCommand());

Modified: trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/cmd/WSConsume.java
===================================================================
--- trunk/jbossws-core/ant-import/build-release.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/jbossws-core/ant-import/build-release.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -28,7 +28,7 @@
         <include name="jboss-jaxws.jar"/>
         <include name="jboss-saaj.jar"/>
         <include name="jbossws-core-src.zip"/>
-        <include name="jbossws-resources.zip"/>
+        <include name="jbossws-core-scripts.zip"/>
       </fileset>
     </copy>
     <copy tofile="${jboss.repository.dir}/jbossws/${repository.id}/component-info.xml" file="${core.output.etc.dir}/component-info.xml" filtering="true" overwrite="true">

Modified: trunk/jbossws-core/src/main/etc/component-info.xml
===================================================================
--- trunk/jbossws-core/src/main/etc/component-info.xml	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/jbossws-core/src/main/etc/component-info.xml	2007-07-09 11:32:21 UTC (rev 3822)
@@ -11,7 +11,7 @@
     <artifact id="jboss-jaxws.jar"/>
     <artifact id="jboss-saaj.jar"/>
     <artifact id="jbossws-core-src.zip"/>
-    <artifact id="jbossws-resources.zip"/>
+    <artifact id="jbossws-core-scripts.zip"/>
 
     <import componentref="apache-xmlsec">
       <compatible version="@apache-xmlsec@"/>
@@ -21,19 +21,12 @@
       <compatible version="@ibm-wsdl4j@"/>
       <compatible version="@ibm-wsdl4j at -brew"/>
     </import>
-    <import componentref="javassist">
-      <compatible version="@javassist@"/>
-      <compatible version="@javassist at -brew"/>
-    </import>
     <import componentref="jbpm/bpel">
       <compatible version="@jbpm-bpel@"/>
     </import>
     <import componentref="jboss/jbossws-spi">
       <compatible version="@repository.id@"/>
     </import>
-    <import componentref="jboss/remoting">
-      <compatible version="@jboss-remoting@"/>
-    </import>
     <import componentref="stax-api">
       <compatible version="@stax-api@"/>
     </import>
@@ -43,6 +36,9 @@
     <import componentref="sun-jaxws">
       <compatible version="@sun-jaxws@"/>
     </import>
+    <import componentref="wscommons-policy">
+      <compatible version="@wscommons-policy@"/>
+    </import>
     
     <export>
       <include input="jbossws-core.jar"/>

Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/impl/SunRIConsumerImpl.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/impl/SunRIConsumerImpl.java	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/impl/SunRIConsumerImpl.java	2007-07-09 11:32:21 UTC (rev 3822)
@@ -48,6 +48,7 @@
    private PrintStream messageStream;
    private String wsdlLocation;
    private List<String> additionalCompilerClassPath;
+   private String target = "2.0";
 
    @Override
    public void setBindingFiles(List<File> bindingFiles)
@@ -102,6 +103,11 @@
       this.additionalCompilerClassPath = additionalCompilerClassPath;
    }
 
+   public void setTarget(String target)
+   {      
+      this.target = target;
+   }
+
    @Override
    public void consume(URL wsdl)
    {
@@ -163,8 +169,14 @@
       // Always add the output directory and the wsdl location
       args.add("-d");
       args.add(outputDir.getAbsolutePath());
+
+      // Always set the target
+      args.add("-target");
+      args.add(target);
+
+      // finally the WSDL file
       args.add(wsdl.toString());
-
+      
       try
       {
          // enforce woodstox
@@ -172,10 +184,10 @@
             System.setProperty("javax.xml.stream.XMLInputFactory", "com.ctc.wstx.stax.WstxInputFactory");
 
          WsimportTool compileTool = new WsimportTool(stream);
-         boolean success = compileTool.run(args.toArray(new String[0]));
+         boolean success = compileTool.run(args.toArray(new String[args.size()]));
 
          if (!success)
-            throw new IllegalStateException("WsImport invocation failed");
+            throw new IllegalStateException("WsImport invocation failed. Try the verbose switch for more information");
       }
       catch (Throwable t)
       {

Modified: trunk/jbossws-core/src/test/resources/jaxrpc/xop/schema.xsd
===================================================================
--- trunk/jbossws-core/src/test/resources/jaxrpc/xop/schema.xsd	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/jbossws-core/src/test/resources/jaxrpc/xop/schema.xsd	2007-07-09 11:32:21 UTC (rev 3822)
@@ -3,7 +3,7 @@
           xmlns:xmime="http://www.w3.org/2005/05/xmlmime"
           xmlns:tns="http://jboss.org/test/ws/xop/doclit">
 
-   <s:import schemaLocation="http://www.w3.org/2005/05/xmlmime" namespace="http://www.w3.org/2005/05/xmlmime"/>
+   <s:import schemaLocation="xml-media-types.xsd" namespace="http://www.w3.org/2005/05/xmlmime"/>
 
    <s:element name="PingMsg">
       <s:complexType>

Copied: trunk/jbossws-core/src/test/resources/jaxrpc/xop/xml-media-types.xsd (from rev 3817, branches/jbossws-2.0/jbossws-core/src/test/resources/jaxrpc/xop/xml-media-types.xsd)
===================================================================
--- trunk/jbossws-core/src/test/resources/jaxrpc/xop/xml-media-types.xsd	                        (rev 0)
+++ trunk/jbossws-core/src/test/resources/jaxrpc/xop/xml-media-types.xsd	2007-07-09 11:32:21 UTC (rev 3822)
@@ -0,0 +1,36 @@
+<!-- 
+  Describing Media Content of Binary Data in XML
+  http://www.w3.org/TR/2005/NOTE-xml-media-types-20050504
+-->
+
+<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema" 
+  xmlns:xmime="http://www.w3.org/2005/05/xmlmime" 
+  targetNamespace="http://www.w3.org/2005/05/xmlmime">
+  
+  <xs:attribute name="contentType">
+    <xs:simpleType>
+      <xs:restriction base="xs:string">
+        <xs:minLength value="3"/>
+      </xs:restriction>
+    </xs:simpleType>
+  </xs:attribute>
+  
+  <xs:attribute name="expectedContentTypes" type="xs:string"/>
+  
+  <xs:complexType name="base64Binary">
+    <xs:simpleContent>
+      <xs:extension base="xs:base64Binary">
+        <xs:attribute ref="xmime:contentType"/>
+      </xs:extension>
+    </xs:simpleContent>
+  </xs:complexType>
+  
+  <xs:complexType name="hexBinary">
+    <xs:simpleContent>
+      <xs:extension base="xs:hexBinary">
+        <xs:attribute ref="xmime:contentType"/>
+      </xs:extension>
+    </xs:simpleContent>
+  </xs:complexType>
+  
+</xs:schema>
\ No newline at end of file




More information about the jbossws-commits mailing list
--- trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/cmd/WSConsume.java	2007-07-09 11:31:57 UTC (rev 3821)
+++ trunk/integration/spi/src/main/java/org/jboss/wsf/spi/tools/cmd/WSConsume.java	2007-07-09 11:32:21 UTC (rev 3822)
@@ -35,23 +35,24 @@
 /**
  * WSConsumeTask is a cmd line tool that generates portable JAX-WS artifacts
  * from a WSDL file.
- * 
+ *
  * <pre>
  *  usage: WSConsumeTask [options] &lt;wsdl-url&gt;
  *  options: 
  *  -h, --help                  Show this help message
  *  -b, --binding=&lt;file&gt;        One or more JAX-WS or JAXB binding files 
  *  -k, --keep                  Keep/Generate Java source
  *  -c  --catalog=&lt;file&gt;        Oasis XML Catalog file for entity resolution
  *  -p  --package=&lt;name&gt;        The target package for generated source
  *  -w  --wsdlLocation=&lt;loc&gt;    Value to use for @@WebService.wsdlLocation
  *  -o, --output=&lt;directory&gt;    The directory to put generated artifacts
  *  -s, --source=&lt;directory&gt;    The directory to put Java source
  *  -q, --quiet                 Be somewhat more quiet
  *  -t, --show-traces           Show full exception stack traces
  *  -l, --load-consumer           Load the consumer and exit (debug utility)
  * </pre>
- * 
+ *
  * @author <a href="mailto:jason.greene at jboss.com">Jason T. Greene</a>
  * @version $Revision$
  */
@@ -63,11 +64,12 @@
    private String targetPackage = null;
    private String wsdlLocation = null;
    private boolean quiet = false;
-   private boolean showTraces = false;
+   private boolean verbose = false;
    private boolean loadConsumer = false;
    private File outputDir = new File("output");
    private File sourceDir = null;
-   
+   private String target = null;
+
    public static String PROGRAM_NAME = System.getProperty("program.name", WSConsume.class.getName());
 
    public static void main(String[] args)
@@ -76,25 +78,26 @@
       URL wsdl = importer.parseArguments(args);
       System.exit(importer.importServices(wsdl));
    }
-   
+
    private URL parseArguments(String[] args)
    {
-      String shortOpts = "hb:kc:p:w:o:s:qtl";
-      LongOpt[] longOpts = 
+      String shortOpts = "b:c:p:w:o:s:t:khqvl";
+      LongOpt[] longOpts =
       {
-         new LongOpt("help", LongOpt.NO_ARGUMENT, null, 'h'),
          new LongOpt("binding", LongOpt.REQUIRED_ARGUMENT, null, 'b'),
-         new LongOpt("keep", LongOpt.NO_ARGUMENT, null, 'k'),
          new LongOpt("catalog", LongOpt.REQUIRED_ARGUMENT, null, 'c'),
          new LongOpt("package", LongOpt.REQUIRED_ARGUMENT, null, 'p'),
          new LongOpt("wsdlLocation", LongOpt.REQUIRED_ARGUMENT, null, 'w'),
          new LongOpt("output", LongOpt.REQUIRED_ARGUMENT, null, 'o'),
          new LongOpt("source", LongOpt.REQUIRED_ARGUMENT, null, 's'),
+         new LongOpt("target", LongOpt.REQUIRED_ARGUMENT, null, 't'),
+         new LongOpt("keep", LongOpt.NO_ARGUMENT, null, 'k'),
+         new LongOpt("help", LongOpt.NO_ARGUMENT, null, 'h'),
          new LongOpt("quiet", LongOpt.NO_ARGUMENT, null, 'q'),
-         new LongOpt("show-traces", LongOpt.NO_ARGUMENT, null, 't'),
+         new LongOpt("verbose", LongOpt.NO_ARGUMENT, null, 'v'),
          new LongOpt("load-consumer", LongOpt.NO_ARGUMENT, null, 'l'),
       };
-      
+
       Getopt getopt = new Getopt(PROGRAM_NAME, args, shortOpts, longOpts);
       int c;
       while ((c = getopt.getopt()) != -1)
@@ -122,11 +125,14 @@
             case 's':
                sourceDir = new File(getopt.getOptarg());
                break;
+            case 't':
+               target = getopt.getOptarg();
+               break;
             case 'q':
                quiet = true;
                break;
-            case 't':
-               showTraces = true;
+            case 'v':
+               verbose = true;
                break;
             case 'l':
                loadConsumer = true;
@@ -154,7 +160,7 @@
          printHelp();
          System.exit(1);
       }
-      
+
       URL url = null;
       try
       {
@@ -173,11 +179,11 @@
          System.err.println("Error: Invalid URI: " + args[wsdlPos]);
          System.exit(1);
       }
-      
+
       return url;
    }
-   
-   
+
+
    private int importServices(URL wsdl)
    {
       WSContractConsumer importer = WSContractConsumer.newInstance();
@@ -189,19 +195,22 @@
 
       if (! quiet)
          importer.setMessageStream(System.out);
-      
+
       if (catalog != null)
          importer.setCatalog(catalog);
-      
+
       if (targetPackage != null)
          importer.setTargetPackage(targetPackage);
-      
+
       if (wsdlLocation != null)
          importer.setWsdlLocation(wsdlLocation);
-      
+
       if (bindingFiles != null && bindingFiles.size() > 0)
          importer.setBindingFiles(bindingFiles);
-      
+
+      if(target!=null)
+         importer.setTarget(target);
+
       try
       {
          importer.consume(wsdl);
@@ -209,8 +218,8 @@
       }
       catch (Throwable t)
       {
-         System.err.println("Error: Could not import. (use --show-traces to see full traces)");
-         if (!showTraces)
+         System.err.println("Error: Could not import. (use --verbose to see full traces)");
+         if (!verbose)
          {
             String message = t.getMessage();
             if (message == null)
@@ -221,9 +230,9 @@
          {
             t.printStackTrace(System.err);
          }
-         
+
       }
-      
+
       return 1;
    }
 
@@ -241,8 +250,9 @@
       out.println("    -w  --wsdlLocation=<loc>    Value to use for @WebService.wsdlLocation");
       out.println("    -o, --output=<directory>    The directory to put generated artifacts");
       out.println("    -s, --source=<directory>    The directory to put Java source");
+      out.println("    -t, --target=<2.0|2.1>      The JAX-WS specification target");
       out.println("    -q, --quiet                 Be somewhat more quiet");
-      out.println("    -t, --show-traces           Show full exception stack traces");
+      out.println("    -v, --verbose               Show full exception stack traces");
       out.println("    -l, --load-consumer         Load the consumer and exit (debug utility)");
       out.flush();
    }
@@ -35,23 +35,24 @@
  * <pre>
  *  usage: WSConsumeTask [options] &lt;wsdl-url&gt;
- *  options: 
- *  -h, --help                  Show this help message
- *  -b, --binding=&lt;file&gt;        One or more JAX-WS or JAXB binding files 
- *  -k, --keep                  Keep/Generate Java source
- *  -c  --catalog=&lt;file&gt;        Oasis XML Catalog file for entity resolution
- *  -p  --package=&lt;name&gt;        The target package for generated source
- *  -w  --wsdlLocation=&lt;loc&gt;    Value to use for @@WebService.wsdlLocation
- *  -o, --output=&lt;directory&gt;    The directory to put generated artifacts
- *  -s, --source=&lt;directory&gt;    The directory to put Java source
- *  -q, --quiet                 Be somewhat more quiet
- *  -t, --show-traces           Show full exception stack traces
- *  -l, --load-consumer           Load the consumer and exit (debug utility)
+ *  options:
+ *  -h, --help                     Show this help message
+ *  -b, --binding=&lt;file&gt;     One or more JAX-WS or JAXB binding files
+ *  -k, --keep                     Keep/Generate Java source
+ *  -c  --catalog=&lt;file&gt;     Oasis XML Catalog file for entity resolution
+ *  -p  --package=&lt;name&gt;     The target package for generated source
+ *  -w  --wsdlLocation=&lt;loc&gt; Value to use for @@WebService.wsdlLocation
+ *  -o, --output=&lt;directory&gt; The directory to put generated artifacts
+ *  -s, --source=&lt;directory&gt; The directory to put Java source
+ *  -t, --target=&lt;2.0|2.1&gt;   The target specification target
+ *  -q, --quiet                    Be somewhat more quiet
+ *  -v, --verbose                  Show full exception stack traces
+ *  -l, --load-consumer            Load the consumer and exit (debug utility)
  * </pre>

Modified: trunk/jbossws-core/ant-import/build-release.xml
===================================================================